import request from '@/api/request'
import { platform } from '@/utils/platform'
import funWxShare from '@/utils/wxShare0.0'

const state = {
  userinfo: {
    user_head_img_url: '', // 用户头像
    user_nickname: '', // 用户昵称
    user_sex: '', // 用户性别
    user_balance: 0, // 用户可提现余额(单位为分)
    user_crash_balance: 0, // 累计提现(单位为分)
    user_unreceive_balance: 0, // 用户未结算金额(单位为分)
    created_at: '', // 注册时间
    id: '', // 用户ID
    last_month_money: '', // 上月预估收益
    month_money: '' // 本月预估收益
  },
  orderType: [], // 订单类型
  inviteId: '', // 邀请人ID，分享链接携带
  isInit: false, // 获取用户信息接口、订单类型接口加锁
  // 商家列表
  sourceList: [
    {
      name: '京东',
      value: 'jd',
      default: require('../../assets/businessLogo/jd0.png'),
      active: require('../../assets/businessLogo/jd1.png'),
      logo: require('../../assets/businessLogo/jd2.png')
    },
    {
      name: '唯品会',
      value: 'vip',
      default: require('../../assets/businessLogo/vip0.png'),
      active: require('../../assets/businessLogo/vip1.png'),
      logo: require('../../assets/businessLogo/vip2.png')
    },
    {
      name: '拼多多',
      value: 'pdd',
      default: require('../../assets/businessLogo/pdd0.png'),
      active: require('../../assets/businessLogo/pdd1.png'),
      logo: require('../../assets/businessLogo/pdd2.png')
    },
    {
      name: '考拉',
      value: 'kaola',
      default: require('../../assets/businessLogo/kaola0.png'),
      active: require('../../assets/businessLogo/kaola1.png'),
      logo: require('../../assets/businessLogo/kaola2.png')
    },
    {
      name: '淘宝',
      value: 'taobao',
      default: require('../../assets/businessLogo/taobao0.png'),
      active: require('../../assets/businessLogo/taobao1.png'),
      logo: require('../../assets/businessLogo/taobao2.png')
    }
  ],
  orderPlatformType: ['', '淘宝', '拼多多', '京东', '美团', '返不停'],
  allOrderStatus: ['未支付', '已支付', '已收货', '已结算', '全部退款或风控', '部分退款', '已取消']
}

const getters = {
  userinfo (state) {
    return state.userinfo
  },
  orderType (state) {
    return state.orderType
  },
  inviteId (state) {
    return state.inviteId
  },
  isInit (state) {
    return state.isInit
  },
  sourceList (state) {
    return state.sourceList
  },
  orderPlatformType (state) {
    return state.orderPlatformType
  },
  allOrderStatus (state) {
    return state.allOrderStatus
  }
}

const actions = {
  async getUserInfo ({ commit }) {
    try {
      const { status, data } = await request({
        method: 'GET',
        url: '/api/user/info'
      })
      if (status) {
        commit('UPDATE_USERINFO', data)
        platform.isWeixin && funWxShare('返不停', '一个省钱、赚钱又返钱的生活平台', `${location.origin}/img/share.png`, `${location.origin}?invite_id=${data.id}`)
      }
    } catch (err) {
      console.log(err)
    }
  },
  async getOrdertype ({ commit }) {
    try {
      const { status, data } = await request({
        method: 'GET',
        url: '/api/order/type/list'
      })
      if (status) {
        commit('UPDATE_ORDER_TYPE', data)
      }
    } catch (err) {
      console.log(err)
    }
  }
}

const mutations = {
  UPDATE_USERINFO (state, value) {
    state.userinfo = {
      ...value
    }
  },
  UPDATE_ORDER_TYPE (state, value) {
    state.orderType = [...value]
  },
  UPDATE_INVITE_ID (state, value) {
    state.inviteId = value
  },
  UPDATE_ISINIT (state, value) {
    state.isInit = value
  }
}

export default {
  namespaced: true,
  state,
  getters,
  actions,
  mutations
}
